summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/Kolinestyleaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficeui/Kolinestyleaction.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/Kolinestyleaction.h')
-rw-r--r--lib/kofficeui/Kolinestyleaction.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kofficeui/Kolinestyleaction.h b/lib/kofficeui/Kolinestyleaction.h
index 6d8d9e91..63be979c 100644
--- a/lib/kofficeui/Kolinestyleaction.h
+++ b/lib/kofficeui/Kolinestyleaction.h
@@ -31,20 +31,20 @@ class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
/** Constructs a KoLineStyleAction with a text and an icon.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- KoLineStyleAction(const TQString& text, const TQString& icon, TQObject* tqparent = 0, const char* name = 0);
+ KoLineStyleAction(const TQString& text, const TQString& icon, TQObject* parent = 0, const char* name = 0);
/** Same as above, but it also connects a slot to the selectionChanged(int) signal.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke when a selectionChanged(int) signal is emited.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
KoLineStyleAction(const TQString& text, const TQString& icon, const TQObject* receiver,
- const char* slot, TQObject* tqparent, const char* name = 0);
+ const char* slot, TQObject* parent, const char* name = 0);
~KoLineStyleAction();
protected:
@@ -31,20 +31,20 @@ class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -31,20 +31,20 @@ class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke when a selectionChanged(int) signal is emited.
@@ -31,20 +31,20 @@ class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
* @param slot The TQT_SLOT to invoke when a selectionChanged(int) signal is emited.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/